==> redux-schema-4.4.2.tgz: package/es/types/basic.js <==
import finalizeType from '../parse/finalize-type';
import { pathToStr } from '../utils';

export function functionIsType(func) {
  return func && (func === String || func === Number || func === Boolean || func === Error || func === RegExp || func === Date || func === Array || func === Object || func.isType === true);
}

var basicTypeHandlers = {
  String: {
    name: 'string',
    is: function is(v) {
      return typeof v === 'string';
    },
    defaultValue: ''
  },
  Number: {
    name: 'number',
    is: function is(v) {
      return typeof v === 'number';
    },
    defaultValue: 0
  },
  Boolean: {
    name: 'boolean',
    is: function is(v) {
      return typeof v === 'boolean';
    },
    defaultValue: false
  },
  Null: {
    name: 'null',
    is: function is(v) {
      return v === null;
    },
    defaultValue: null
  },
  Undefined: {
    name: 'undefined',
    is: function is(v) {
      return typeof v === 'undefined';
    },
    defaultValue: undefined
  }
};

function basicType(options, type) {
  var upName = type.name[0].toUpperCase() + type.name.substr(1);

  return finalizeType({
    isType: true,
    name: pathToStr(options.typeMoniker) || type.name,
    kind: type.name,
    storageKinds: [type.name],
    options: options,
    validateData: function validateData(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!type.is(value)) {
        return 'Type of "' + pathToStr(instancePath) + '" data must be ' + type.name;
      }
    },
    validateAssign: function validateAssign(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!type.is(value)) {
        return 'Type of "' + pathToStr(instancePath) + '" must be ' + type.name;
      }
    },
    pack: function pack(value) {
      return value;
    },
    unpack: function unpack(store, path, instancePath, currentInstance) {
      if (currentInstance) throw new Error(upName + ' types cannot modify a data instance');
      return store.get(path);
    },
    getTypeFromPath: function getTypeFromPath(path) {
      if (path.length) throw new Error('Cannot get type path for properties of ' + type.name + 's');
      return options.typeMoniker;
    },
    defaultValue: function defaultValue() {
      return type.defaultValue;
    }
  });
}

var _basicTypes = {};

Object.keys(basicTypeHandlers).forEach(function (name) {
  return _basicTypes[name.toLowerCase()] = function (options) {
    return basicType(options, basicTypeHandlers[name]);
  };
});

export var basicTypes = _basicTypes;

==> redux-schema-4.8.0.tgz: package/es/types/basic.js <==
import finalizeType from '../parse/finalize-type';
import { pathToStr } from '../utils';

export function functionIsType(func) {
  return func && (func === String || func === Number || func === Boolean || func === Error || func === RegExp || func === Date || func === Array || func === Object || func.isType === true);
}

var basicTypeHandlers = {
  String: {
    name: 'string',
    is: function is(v) {
      return typeof v === 'string';
    },
    defaultValue: '',
    coerce: function coerce(v) {
      if (v === undefined || v === null) {
        return '';
      }
      return String(v);
    }
  },
  Number: {
    name: 'number',
    is: function is(v) {
      return typeof v === 'number';
    },
    defaultValue: 0,
    coerce: function coerce(v) {
      var n = Number(v);
      return isNaN(n) ? 0 : n;
    }
  },
  Boolean: {
    name: 'boolean',
    is: function is(v) {
      return typeof v === 'boolean';
    },
    defaultValue: false,
    coerce: function coerce(v) {
      return Boolean(v);
    }
  },
  Null: {
    name: 'null',
    is: function is(v) {
      return v === null;
    },
    defaultValue: null,
    coerce: function coerce() {
      return null;
    }
  },
  Undefined: {
    name: 'undefined',
    is: function is(v) {
      return typeof v === 'undefined';
    },
    defaultValue: undefined,
    coerce: function coerce() {
      return undefined;
    }
  }
};

function basicType(options, type) {
  var upName = type.name[0].toUpperCase() + type.name.substr(1);

  var thisType = finalizeType({
    isType: true,
    name: pathToStr(options.typeMoniker) || type.name,
    kind: type.name,
    storageKinds: [type.name],
    options: options,
    validateData: function validateData(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!type.is(value)) {
        return 'Type of "' + pathToStr(instancePath) + '" data must be ' + type.name;
      }
    },
    coerceData: function coerceData(value) {
      if (!thisType.validateData(value)) return value;
      return type.coerce(value);
    },
    validateAssign: function validateAssign(value, instancePath) {
      instancePath = instancePath || options.typeMoniker;
      if (!type.is(value)) {
        return 'Type of "' + pathToStr(instancePath) + '" must be ' + type.name;
      }
    },
    pack: function pack(value) {
      return value;
    },
    unpack: function unpack(store, path, instancePath, currentInstance) {
      if (currentInstance) throw new Error(upName + ' types cannot modify a data instance');
      return store.get(path);
    },
    getTypeFromPath: function getTypeFromPath(path) {
      if (path.length) throw new Error('Cannot get type path for properties of ' + type.name + 's');
      return options.typeMoniker;
    },
    defaultValue: function defaultValue() {
      return type.defaultValue;
    }
  });
  return thisType;
}

var _basicTypes = {};

Object.keys(basicTypeHandlers).forEach(function (name) {
  return _basicTypes[name.toLowerCase()] = function (options) {
    return basicType(options, basicTypeHandlers[name]);
  };
});

export var basicTypes = _basicTypes;
